==> zio-aws-waf_2.13-5.17.104.1-sources.jar: zio/aws/waf/model/ListRuleGroupsRequest.scala <==
package zio.aws.waf.model
import java.lang.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.waf.model.primitives.{PaginationLimit, NextMarker}
import scala.jdk.CollectionConverters._
final case class ListRuleGroupsRequest(
    nextMarker: Option[NextMarker] = None,
    limit: Option[PaginationLimit] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.waf.model.ListRuleGroupsRequest = {
    import ListRuleGroupsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.waf.model.ListRuleGroupsRequest
      .builder()
      .optionallyWith(
        nextMarker.map(value => NextMarker.unwrap(value): java.lang.String)
      )(_.nextMarker)
      .optionallyWith(
        limit.map(value => PaginationLimit.unwrap(value): Integer)
      )(_.limit)
      .build()
  }
  def asReadOnly: zio.aws.waf.model.ListRuleGroupsRequest.ReadOnly =
    zio.aws.waf.model.ListRuleGroupsRequest.wrap(buildAwsValue())
}
object ListRuleGroupsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.waf.model.ListRuleGroupsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.waf.model.ListRuleGroupsRequest =
      zio.aws.waf.model.ListRuleGroupsRequest(
        nextMarker.map(value => value),
        limit.map(value => value)
      )
    def nextMarker: Option[NextMarker]
    def limit: Option[PaginationLimit]
    def getNextMarker: ZIO[Any, AwsError, NextMarker] =
      AwsError.unwrapOptionField("nextMarker", nextMarker)
    def getLimit: ZIO[Any, AwsError, PaginationLimit] =
      AwsError.unwrapOptionField("limit", limit)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.waf.model.ListRuleGroupsRequest
  ) extends zio.aws.waf.model.ListRuleGroupsRequest.ReadOnly {
    override val nextMarker: Option[NextMarker] = scala
      .Option(impl.nextMarker())
      .map(value => zio.aws.waf.model.primitives.NextMarker(value))
    override val limit: Option[PaginationLimit] = scala
      .Option(impl.limit())
      .map(value => zio.aws.waf.model.primitives.PaginationLimit(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.waf.model.ListRuleGroupsRequest
  ): zio.aws.waf.model.ListRuleGroupsRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-waf_2.13-5.17.176.2-sources.jar: zio/aws/waf/model/ListRuleGroupsRequest.scala <==
package zio.aws.waf.model
import zio.aws.waf.model.primitives.{PaginationLimit, NextMarker}
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class ListRuleGroupsRequest(
    nextMarker: Optional[NextMarker] = Optional.Absent,
    limit: Optional[PaginationLimit] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.waf.model.ListRuleGroupsRequest = {
    import ListRuleGroupsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.waf.model.ListRuleGroupsRequest
      .builder()
      .optionallyWith(
        nextMarker.map(value => NextMarker.unwrap(value): java.lang.String)
      )(_.nextMarker)
      .optionallyWith(
        limit.map(value => PaginationLimit.unwrap(value): Integer)
      )(_.limit)
      .build()
  }
  def asReadOnly: zio.aws.waf.model.ListRuleGroupsRequest.ReadOnly =
    zio.aws.waf.model.ListRuleGroupsRequest.wrap(buildAwsValue())
}
object ListRuleGroupsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.waf.model.ListRuleGroupsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.waf.model.ListRuleGroupsRequest =
      zio.aws.waf.model.ListRuleGroupsRequest(
        nextMarker.map(value => value),
        limit.map(value => value)
      )
    def nextMarker: Optional[NextMarker]
    def limit: Optional[PaginationLimit]
    def getNextMarker: ZIO[Any, AwsError, NextMarker] =
      AwsError.unwrapOptionField("nextMarker", nextMarker)
    def getLimit: ZIO[Any, AwsError, PaginationLimit] =
      AwsError.unwrapOptionField("limit", limit)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.waf.model.ListRuleGroupsRequest
  ) extends zio.aws.waf.model.ListRuleGroupsRequest.ReadOnly {
    override val nextMarker: Optional[NextMarker] = zio.aws.core.internal
      .optionalFromNullable(impl.nextMarker())
      .map(value => zio.aws.waf.model.primitives.NextMarker(value))
    override val limit: Optional[PaginationLimit] = zio.aws.core.internal
      .optionalFromNullable(impl.limit())
      .map(value => zio.aws.waf.model.primitives.PaginationLimit(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.waf.model.ListRuleGroupsRequest
  ): zio.aws.waf.model.ListRuleGroupsRequest.ReadOnly = new Wrapper(impl)
}
